# User Guide

**Rekha bridges the plotting library gap:** Get Plotly Express's semantic simplicity with matplotlib's publication-quality output and unlimited customization.

## Plot Types

```{toctree}
:maxdepth: 2

plots/index
```

## Advanced Features

```{toctree}
:maxdepth: 2

advanced/index
```

## Quick Reference

- {doc}`Quickstart <../quickstart>` - Get started in 2 minutes
- {doc}`API Reference <../api/index>` - Complete parameter documentation
- [Examples](https://github.com/project-vajra/rekha/tree/main/examples) - Browse runnable code